@@ -155,8 +155,8 @@ void RevokeCertificationCommand::Private::ensureDialogCreated()
     applyWindowID(dialog);
     dialog->setAttribute(Qt::WA_DeleteOnClose);
 
-    connect(dialog, SIGNAL(accepted()), q, SLOT(slotDialogAccepted()));
-    connect(dialog, SIGNAL(rejected()), q, SLOT(slotDialogRejected()));
+    connect(dialog, &QDialog::accepted, q, [this]() { slotDialogAccepted(); });
+    connect(dialog, &QDialog::rejected, q, [this]() { slotDialogRejected(); });
 }
 
 QGpgME::QuickJob *RevokeCertificationCommand::Private::createJob()
@@ -173,8 +173,7 @@ QGpgME::QuickJob *RevokeCertificationCommand::Private::createJob()
     if (j) {
         connect(j, &Job::progress,
                 q, &Command::progress);
-        connect(j, SIGNAL(result(GpgME::Error)),
-                q, SLOT(slotResult(GpgME::Error)));
+        connect(j, &QGpgME::QuickJob::result, q, [this](const GpgME::Error &error) { slotResult(error); });
     }
 
     return j;
@@ -186,6 +185,12 @@ RevokeCertificationCommand::RevokeCertificationCommand(QAbstractItemView *v, Key
     d->init();
 }
 
+RevokeCertificationCommand::RevokeCertificationCommand(const GpgME::Key &key)
+    : Command(key, new Private(this, nullptr))
+{
+    d->init();
+}
+
 RevokeCertificationCommand::RevokeCertificationCommand(const GpgME::UserID &uid)
     : Command(uid.parent(), new Private(this, nullptr))
 {
@@ -193,6 +198,13 @@ RevokeCertificationCommand::RevokeCertificationCommand(const GpgME::UserID &uid)
     d->init();
 }
 
+RevokeCertificationCommand::RevokeCertificationCommand(const std::vector<GpgME::UserID> &uids)
+    : Command{uids.empty() ? Key{} : uids.front().parent(), new Private{this, nullptr}}
+{
+    d->uids = uids;
+    d->init();
+}
+
 RevokeCertificationCommand::RevokeCertificationCommand(const GpgME::UserID::Signature &signature)
     : Command(signature.parent().parent(), new Private(this, nullptr))
 {
@@ -221,7 +233,7 @@ void RevokeCertificationCommand::doStart()
 
     for (const UserID &uid : std::as_const(d->uids))
         if (qstricmp(uid.parent().primaryFingerprint(), d->certificationTarget.primaryFingerprint()) != 0) {
-            qCWarning(KLEOPATRA_LOG) << "User-ID <-> Key mismatch!";
+            qCWarning(KLEOPATRA_LOG) << "User ID <-> Key mismatch!";
             d->finished();
             return;
         }
