@@ -28,7 +28,6 @@
 
 #include <Libkleo/DefaultKeyFilter>
 #include <Libkleo/KeyCache>
-#include <Libkleo/KeyGroup>
 #include <Libkleo/KeyListModel>
 #include <Libkleo/KeySelectionCombo>
 #include <Libkleo/KeyListSortFilterProxyModel>
@@ -256,23 +255,30 @@ void SignEncryptWidget::setEncryptWithPasswordText(const QString& text)
 
 CertificateLineEdit *SignEncryptWidget::addRecipientWidget()
 {
+    return insertRecipientWidget(nullptr);
+}
+
+CertificateLineEdit *SignEncryptWidget::insertRecipientWidget(CertificateLineEdit *after)
+{
+    Q_ASSERT(!after || mRecpLayout->indexOf(after) != -1);
+
+    const auto index = after ? mRecpLayout->indexOf(after) + 1 : mRecpLayout->count();
+
     auto certSel = new CertificateLineEdit(mModel,
                                            new EncryptCertificateFilter(mCurrentProto),
                                            this);
     certSel->setAccessibleNameOfLineEdit(i18nc("text for screen readers", "recipient key"));
     certSel->setEnabled(mEncOtherChk->isChecked());
-    mRecpWidgets << certSel;
+    mRecpWidgets.insert(index, certSel);
 
     if (mRecpLayout->count() > 0) {
-        auto lastWidget = mRecpLayout->itemAt(mRecpLayout->count() - 1)->widget();
-        setTabOrder(lastWidget, certSel);
+        auto prevWidget = after ? after : mRecpLayout->itemAt(mRecpLayout->count() - 1)->widget();
+        setTabOrder(prevWidget, certSel);
     }
-    mRecpLayout->addWidget(certSel);
+    mRecpLayout->insertWidget(index, certSel);
 
     connect(certSel, &CertificateLineEdit::keyChanged,
             this, &SignEncryptWidget::recipientsChanged);
-    connect(certSel, &CertificateLineEdit::wantsRemoval,
-            this, &SignEncryptWidget::recpRemovalRequested);
     connect(certSel, &CertificateLineEdit::editingStarted,
             this, &SignEncryptWidget::recipientsChanged);
     connect(certSel, &CertificateLineEdit::certificateSelectionRequested,
@@ -326,22 +332,22 @@ void SignEncryptWidget::certificateSelectionRequested(CertificateLineEdit *certi
         if (keys.size() == 0 && groups.size() == 0) {
             return;
         }
-        bool isFirstItem = true;
+        CertificateLineEdit *certWidget = nullptr;
         for (const Key &key : keys) {
-            if (isFirstItem) {
-                certificateLineEdit->setKey(key);
-                isFirstItem = false;
+            if (!certWidget) {
+                certWidget = certificateLineEdit;
             } else {
-                addRecipient(key);
+                certWidget = insertRecipientWidget(certWidget);
             }
+            certWidget->setKey(key);
         }
         for (const KeyGroup &group : groups) {
-            if (isFirstItem) {
-                certificateLineEdit->setGroup(group);
-                isFirstItem = false;
+            if (!certWidget) {
+                certWidget = certificateLineEdit;
             } else {
-                addRecipient(group);
+                certWidget = insertRecipientWidget(certWidget);
             }
+            certWidget->setGroup(group);
         }
     }
 
@@ -454,17 +460,17 @@ std::vector<Key> SignEncryptWidget::recipients() const
 bool SignEncryptWidget::isDeVsAndValid() const
 {
     if (!signKey().isNull()
-        && (!IS_DE_VS(signKey()) || keyValidity(signKey()) < GpgME::UserID::Validity::Full)) {
+        && (!signKey().isDeVs() || keyValidity(signKey()) < GpgME::UserID::Validity::Full)) {
         return false;
     }
 
     if (!selfKey().isNull()
-        && (!IS_DE_VS(selfKey()) || keyValidity(selfKey()) < GpgME::UserID::Validity::Full)) {
+        && (!selfKey().isDeVs() || keyValidity(selfKey()) < GpgME::UserID::Validity::Full)) {
         return false;
     }
 
     for (const auto &key: recipients()) {
-        if (!IS_DE_VS(key) || keyValidity(key) < GpgME::UserID::Validity::Full) {
+        if (!key.isDeVs() || keyValidity(key) < GpgME::UserID::Validity::Full) {
             return false;
         }
     }
@@ -497,6 +503,15 @@ QString SignEncryptWidget::currentOp() const
     return mOp;
 }
 
+namespace
+{
+bool recipientWidgetHasFocus(CertificateLineEdit *w)
+{
+    // check if w (or its focus proxy) or a child widget of w has focus
+    return w->hasFocus() || w->isAncestorOf(qApp->focusWidget());
+}
+}
+
 void SignEncryptWidget::recpRemovalRequested(CertificateLineEdit *w)
 {
     if (!w) {
@@ -506,7 +521,7 @@ void SignEncryptWidget::recpRemovalRequested(CertificateLineEdit *w)
         std::count_if(std::cbegin(mRecpWidgets), std::cend(mRecpWidgets),
                       [](auto w) { return w->isEmpty(); });
     if (emptyEdits > 1) {
-        if (w->hasFocus()) {
+        if (recipientWidgetHasFocus(w)) {
             const int index = mRecpLayout->indexOf(w);
             const auto focusWidget = (index < mRecpLayout->count() - 1) ?
                 mRecpLayout->itemAt(index + 1)->widget() :
@@ -628,12 +643,19 @@ void Kleo::SignEncryptWidget::onProtocolChanged()
     }
 }
 
+bool SignEncryptWidget::isComplete() const
+{
+    return !currentOp().isEmpty()
+        && std::all_of(std::cbegin(mRecpWidgets), std::cend(mRecpWidgets),
+                        [](auto w) { return !w->isEnabled() || w->hasAcceptableInput(); });
+}
+
 bool SignEncryptWidget::validate()
 {
     CertificateLineEdit *firstUnresolvedRecipient = nullptr;
     QStringList unresolvedRecipients;
     for (const auto edit: std::as_const(mRecpWidgets)) {
-        if (edit->isEnabled() && !edit->isEmpty() && edit->key().isNull() && edit->group().isNull()) {
+        if (edit->isEnabled() && !edit->hasAcceptableInput()) {
             if (!firstUnresolvedRecipient) {
                 firstUnresolvedRecipient = edit;
             }
