@@ -8,6 +8,8 @@
 */
 #include "updatenotification.h"
 
+#include <view/htmllabel.h>
+
 #include <Libkleo/Compat>
 #include <Libkleo/GnuPG>
 
@@ -79,7 +81,11 @@ void UpdateNotification::forceUpdateCheck(QWidget *parent)
                                    << QString::fromLocal8Bit(proc->readAllStandardError());
     });
 
-    connect(proc, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished),
+#if QT_DEPRECATED_SINCE(5, 13)
+    connect(proc, qOverload<int, QProcess::ExitStatus>(&QProcess::finished),
+#else
+    connect(proc, &QProcess::finished,
+#endif
             [parent, progress, proc](int exitCode, QProcess::ExitStatus exitStatus) {
             qCDebug(KLEOPATRA_LOG) << "Update force exited with status:" << exitStatus
                                    << "code:" << exitCode;
@@ -178,9 +184,9 @@ UpdateNotification::UpdateNotification(QWidget *parent, const QString &version)
                                           KIconLoader::User);
     logo->setPixmap(QIcon(iconPath).pixmap(100, 100));
 
-    auto label = new QLabel;
+    auto label = new HtmlLabel;
     const QString boldVersion = QStringLiteral("<b>%1</b>").arg(version);
-    label->setText (i18nc("%1 is the version number", "Version %1 is available.", boldVersion) +
+    label->setHtml(i18nc("%1 is the version number", "Version %1 is available.", boldVersion) +
         QStringLiteral("<br><br>") +
         i18nc("Link to NEWS style changelog",
               "See the <a href=\"https://www.gpg4win.org/change-history.html\">new features</a>."));
